[jboss-cvs] JBossCache/src/org/jboss/cache/rpc ...
Manik Surtani
msurtani at jboss.com
Sat Dec 30 12:50:06 EST 2006
User: msurtani
Date: 06/12/30 12:50:06
Modified: src/org/jboss/cache/rpc RpcTreeCache.java
Log:
Major changes to restructure cache and node object model
Revision Changes Path
1.12 +14 -16 JBossCache/src/org/jboss/cache/rpc/RpcTreeCache.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: RpcTreeCache.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/src/org/jboss/cache/rpc/RpcTreeCache.java,v
retrieving revision 1.11
retrieving revision 1.12
diff -u -b -r1.11 -r1.12
--- RpcTreeCache.java 30 Aug 2006 17:08:18 -0000 1.11
+++ RpcTreeCache.java 30 Dec 2006 17:50:06 -0000 1.12
@@ -1,6 +1,6 @@
package org.jboss.cache.rpc;
-import org.jboss.cache.TreeCache;
+import org.jboss.cache.CacheImpl;
import org.jboss.cache.config.Configuration;
import org.jboss.cache.marshall.MethodCall;
import org.jboss.cache.marshall.MethodCallFactory;
@@ -15,7 +15,7 @@
import java.util.Vector;
/**
* {@link TreeCache} extension that adds a general purpose RPC functionality
* to allow clients to make/receive RPC calls over the same JGroups Channel
* used by the cache.
* <p/>
@@ -28,7 +28,7 @@
* </p>
* <p/>
* <strong>NOTE: </strong> The purpose of this class is to allow services that
* want to use a TreeCache to avoid also having to use a HAPartition (and thus
* potentially requiring a duplicate JGroups Channel).
*
* @author <a href="mailto://brian.stansberry@jboss.com">Brian Stansberry</a>
@@ -36,11 +36,11 @@
* @deprecated This class will be removed when JGroups adds a multiplexing
* capability.
*/
-public class RpcTreeCache extends TreeCache //implements RpcTreeCacheMBean // TODO; Sort out proper JMX interfaces
+public class RpcTreeCache extends CacheImpl //implements RpcTreeCacheMBean // TODO; Sort out proper JMX interfaces
{
/**
- * The {@link #_dispatchRpcCall(String, MethodCall)} method
+ * The {@link #_dispatchRpcCall(String,MethodCall)} method
*/
public static final Method dispatchRpcCallMethod;
@@ -48,9 +48,7 @@
{
try
{
- dispatchRpcCallMethod = RpcTreeCache.class.getDeclaredMethod("_dispatchRpcCall",
- new Class[]{String.class,
- MethodCall.class});
+ dispatchRpcCallMethod = RpcTreeCache.class.getDeclaredMethod("_dispatchRpcCall", String.class, MethodCall.class);
}
catch (NoSuchMethodException ex)
{
@@ -98,10 +96,10 @@
*
* @param serviceName name of a callback handler that will have been
* registered on the remote end via
- * {@link #registerRPCHandler(String, Object)}.
+ * {@link #registerRPCHandler(String,Object)}.
* @param members Vector, each of whose members is the Address of one
* the nodes in the cache's
- * {@link TreeCache#getMembers() member list}.
+ * {@link CacheImpl#getMembers() member list}.
* If <code>null</code>, the method will be invoked on
* all members.
* @param method method to execute
@@ -129,14 +127,14 @@
* Calls a remote method on nodes in the cluster, targeted at
* objects registered under a given <code>serviceName</code>.
* <p/>
* If the cache's <code>cache mode</code> is <code>TreeCache.LOCAL</code>
* and parameter <code>exclude_self</code> is <code>false</code>
* this request will be made directly to
* </p>
*
* @param serviceName name of a callback handler that will have been
* registered on the remote end via
- * {@link #registerRPCHandler(String, Object)}.
+ * {@link #registerRPCHandler(String,Object)}.
* @param method_call method call to execute
* @param synchronous <code>true</code> if the call should block until
* all members respond (or timeout); <code>false</code>
@@ -200,7 +198,7 @@
// Remove any NoHandlerForRPCException
// Its inefficient doing this here, but if we add it to
// TreeCache.callRemoteMethods we slow down normal cache ops
if (responses != null)
{
for (int i = 0; i < responses.size(); i++)
@@ -224,10 +222,10 @@
*
* @param serviceName name of a callback handler that will have been
* registered on the remote end via
- * {@link #registerRPCHandler(String, Object)}.
+ * {@link #registerRPCHandler(String,Object)}.
* @param members Vector, each of whose members is the Address of one
* the nodes in the cache's
- * {@link TreeCache#getMembers() member list}.
+ * {@link CacheImpl#getMembers() member list}.
* If <code>null</code>, the method will be invoked on
* all members.
* @param method_name name of the method to execute
@@ -287,7 +285,7 @@
*
* @param serviceName name of a service that will be receiving RPC calls
* @param handler object that was previously passed to
- * {@link #registerRPCHandler(String, Object)} for
+ * {@link #registerRPCHandler(String,Object)} for
* <code>serviceName</code>.
* @param handler
*/
@@ -15,7 +15,7 @@
import java.util.Vector;
/**
- * {@link TreeCache} extension that adds a general purpose RPC functionality
+ * {@link CacheImpl} extension that adds a general purpose RPC functionality
* to allow clients to make/receive RPC calls over the same JGroups Channel
* used by the cache.
@@ -28,7 +28,7 @@
* <p/>
* <strong>NOTE: </strong> The purpose of this class is to allow services that
- * want to use a TreeCache to avoid also having to use a HAPartition (and thus
+ * want to use a CacheImpl to avoid also having to use a HAPartition (and thus
* potentially requiring a duplicate JGroups Channel).
*
@@ -129,14 +127,14 @@
* objects registered under a given <code>serviceName</code>.
* <p/>
- * If the cache's <code>cache mode</code> is <code>TreeCache.LOCAL</code>
+ * If the cache's <code>cache mode</code> is <code>CacheImpl.LOCAL</code>
* and parameter <code>exclude_self</code> is <code>false</code>
* this request will be made directly to
@@ -200,7 +198,7 @@
// Remove any NoHandlerForRPCException
// Its inefficient doing this here, but if we add it to
- // TreeCache.callRemoteMethods we slow down normal cache ops
+ // CacheImpl.callRemoteMethods we slow down normal cache ops
if (responses != null)
{
More information about the jboss-cvs-commits
mailing list